@@ -40,7 +40,7 @@
 #'
 #' `
 #' mytoken <- readLines("~/Dropbox/dotfiles/cyclestreets-api-key-rl")
-#' Sys.setenv(CYCLESTREET = mytoken)
+#' Sys.setenv(CYCLESTREETS = mytoken)
 #' `
 #'
 #' if you want the API key to be available in future
@@ -57,25 +57,21 @@
 #' @family routes
 #' @export
 #' @seealso line2route
-#' @aliases route_cyclestreets
 #' @examples
 #'
 #' \dontrun{
 #' from <- c(-1.55, 53.80) # geo_code("leeds")
 #' to <- c(-1.76, 53.80) # geo_code("bradford uk")
-#' json_output <- route_cyclestreet(from = from, to = to, plan = "quietest", save_raw = TRUE)
+#' json_output <- route_cyclestreets(from = from, to = to, plan = "quietest", save_raw = TRUE)
 #' str(json_output) # what does cyclestreets give you?
-#' rf_lb <- route_cyclestreet(from, to, plan = "fastest")
+#' rf_lb <- route_cyclestreets(from, to, plan = "fastest")
 #' rf_lb@data
 #' plot(rf_lb)
 #' (rf_lb$length / (1000 * 1.61)) / # distance in miles
 #'   (rf_lb$time / (60 * 60)) # time in hours - average speed here: ~8mph
-#' # Plan a 'balanced' route from Pedaller's Arms to the University of Leeds
-#' rb_pa <- route_cyclestreet("Pedaller's Arms, Leeds", "University of Leeds, UK", "balanced")
 #' }
 #'
-route_cyclestreet <-
-  route_cyclestreets <- function(from, to, plan = "fastest", silent = TRUE, pat = NULL,
+route_cyclestreets <- function(from, to, plan = "fastest", silent = TRUE, pat = NULL,
                                    base_url = "https://www.cyclestreets.net", reporterrors = TRUE,
                                    save_raw = "FALSE") {
 
@@ -217,7 +213,7 @@ route_cyclestreet <-
 #' Where `url` is an example api request from
 #'  <https://github.com/graphhopper/directions-api/blob/master/routing.md>.
 #'
-#' @inheritParams route_cyclestreet
+#' @inheritParams route_cyclestreets
 #' @inheritParams od_coords
 #' @family routes
 #' @export
@@ -305,7 +301,7 @@ route_graphhopper <- function(from, to, l = NULL, vehicle = "bike",
 #' Retrieve personal access token.
 #'
 #' @param api_name Text string of the name of the API you are calling, e.g.
-#' cyclestreet, graphhopper etc.
+#' cyclestreets, graphhopper etc.
 #'
 #' @keywords internal
 #' @export
@@ -324,7 +320,7 @@ api_pat <- function(api_name, force = FALSE) {
     )
   }
 
-  message("Couldn't find the environment variable ", api_name_caps, ". See documentation, e.g. ?route_cyclestreet, for more details.")
+  message("Couldn't find the environment variable ", api_name_caps, ". See documentation, e.g. ?route_cyclestreets, for more details.")
   message("Please enter your API key to access the ", api_name, "and press enter:")
   pat <- readline(": ")
 
